@@ -1,28 +1,31 @@
 # R code for F1_LD_F1 macro
 #
-# Input: 
+# Input:
 #		group: a vector of group variable (factor level)
 #		time : a vector of time variable
 #		subject : a vector of independent subjects
 #		var: a vector of variable of interest
 #
-# Optional Input:	
+# Optional Input:
 #		w.pat: pattern matrix of order group level x time level
-#		w.t : vector of order time level, pattern for interaction 
+#		w.t : vector of order time level, pattern for interaction
 #		w.g : vector of order group level, group pattern
 #		time.name: name of the time vector. "Time" is set as default.
-#		group.name: name of the time vector. "Group" is set as default.  	
+#		group.name: name of the time vector. "Group" is set as default.
 #               description: description of the output. Default is set to TRUE (show description)
 #		time.order: a vector of time levels specifying the order.
 #		group.order: a vector of group levels specifying the order.
+#		plot.RTE: decides whether to show plot of RTE or not. Default is set to TRUE
+#		show.covariance: decides whether to show covariance or not. Default is set to FALSE
 #
 # Output:
 #               list of relative treatment effects, test results, pattern result
 #
-f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL, time.name="Time", group.name="Group", description=TRUE, time.order=NULL, group.order=NULL)
+f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL, time.name="Time", 
+group.name="Group", description=TRUE, time.order=NULL, group.order=NULL, plot.RTE=TRUE, show.covariance=FALSE)
 {
 #        For model description see Brunner et al. (2002)
-#    
+#
 #        Author: Mahbub Latif (mlatif@gwdg.de)
 #                     Department of Medical Statistics, Goettingen, Germany
 #
@@ -52,14 +55,14 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 
 #    check whether the input variables are entered correctly
 
-	   if(is.null(var)||is.null(time)||is.null(group)||is.null(subject)) 
+	   if(is.null(var)||is.null(time)||is.null(group)||is.null(subject))
 		stop("At least one of the input parameters (var, time, group, or subject) is not found.")
-	   
+
            sublen<-length(subject)
 	   varlen<-length(var)
 	   timlen<-length(time)
 	   grolen<-length(group)
-	   
+
 	   if((sublen!=varlen)||(sublen!=timlen)||(sublen!=grolen))
 		stop("At least one of the input parameters (var, time, group, or subject) has a different length.")
 
@@ -85,9 +88,9 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 # tr: calculates the trace of the matrix
 ######################################################################################
 
-	# rte function for relative treatment effects 
+	# rte function for relative treatment effects
 	rte <- function(group, time, indx, rscore)
-	{	
+	{
 		a <- nlevels(group);
 		t <- nlevels(time);
 		tab <- t(matrix(mean.factor(rscore, group:time, indx), t, a))
@@ -97,17 +100,18 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		RankMean <- c(rankmean.g, rankmean.y, rankmean.gy);
 
 		# no of observations per factors
-		Nobs <- c(tapply(indx, group, sum), tapply(indx, time, sum), tapply(indx, group:time, sum)) 
+		Nobs <- c(tapply(indx, group, sum), tapply(indx, time, sum), tapply(indx, group:time, sum))
 
 		# rte
-		RTE <- (1/sum(indx))*(RankMean - 0.5);
-		
+		RTE <- (1/sum(indx))*(RankMean - 0.5)
+
 		# output
-		out <- data.frame(RankMeans=RankMean, Nobs=Nobs, RTE=RTE);
+
+		out <- data.frame(RankMeans=RankMean, Nobs=Nobs, RTE=RTE)
         	levels(group) <- paste(group.name,glevel,sep="")
        		levels(time) <- paste(time.name,tlevel,sep="")
-		row.names(out)<-c(levels(group), levels(time), levels(group:time));
-		return(out);
+		row.names(out)<-c(levels(group), levels(time), levels(group:time))
+		return(out)
 	}
 
 	## Case 2 x 2 as described in 8.1.2.
@@ -119,7 +123,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
        		ind.s <- split(ind, group)
        		sigma2 <- rep(0,2)
        		Un <- 0
-       		Un.const <- 0 
+       		Un.const <- 0
        		v.den <- 0
        		UnT <- 0
        		UnT.c <- 0
@@ -136,17 +140,17 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
           		junk.s <- apply(junk,1,sum)
 
           		# Group effect
-          		Un <- Un + sum(junk.m)*(-1)^(i+1) 
+          		Un <- Un + sum(junk.m)*(-1)^(i+1)
           		sigma2[i] <- sum((junk.s - sum(junk.m))^2)/(nrow(junk)-1)
           		Un.const <- Un.const + sigma2[i]/nrow(junk)
-          		v.den <- v.den+(sigma2[i]/nrow(junk))^2/(nrow(junk)-1) 
+          		v.den <- v.den+(sigma2[i]/nrow(junk))^2/(nrow(junk)-1)
 
           		# Time
           		junk.d <- apply(junk,1,diff)
           		tau2 <- sum((junk.d - diff(junk.m))^2)/(nrow(junk)-1)
           		UnT <- UnT - diff(junk.m)
           		UnT.c <- UnT.c + tau2/nrow(junk)
-          		vT <- vT + (tau2/nrow(junk))^2/(nrow(junk)-1) 
+          		vT <- vT + (tau2/nrow(junk))^2/(nrow(junk)-1)
 
           		# Interaction
           		UnAT <- UnAT + diff(junk.m)*(-1)^i
@@ -156,7 +160,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
        		Un <- Un/sqrt(Un.const)
        		v <- Un.const^2/v.den
 		if(!is.na(Un)&&(v > 0))
-       		{ 
+       		{
 			pGN <- (1-pnorm(abs(Un)))*2
        			pGT <- (1-pt(abs(Un), v))*2
 		}
@@ -169,9 +173,9 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 
        		# Time effect
        		UnT <- UnT/sqrt(UnT.c)
-       		vT <- UnT.c^2/vT 
+       		vT <- UnT.c^2/vT
 		if(!is.na(UnT)&&(vT > 0))
-       		{ 
+       		{
        			pTN <- (1-pnorm(abs(UnT)))*2
        			pTT <- (1-pt(abs(UnT),vT))*2
 		}
@@ -180,7 +184,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 			pTN <- NA
 			pTT <- NA
 		}
-       		out <- rbind(out, c(UnT,pTN,vT,pTT)) 
+       		out <- rbind(out, c(UnT,pTN,vT,pTT))
 
        		# Interaction
        		UnAT <- UnAT/sqrt(UnT.c)
@@ -193,14 +197,14 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		{
 			pATN <- NA
 			pATT <- NA
-		}		
+		}
        		out<- rbind(out, c(UnAT,pATN,vT,pATT))
        		names(out) <- c("Statistic","p-value(N)","df","p-value(T)")
-       		row.names(out) <- c(group.name, time.name, paste(group.name,":",time.name,sep="")) 
-       		return(list(case2x2=out))   
+       		row.names(out) <- c(group.name, time.name, paste(group.name,":",time.name,sep=""))
+       		return(list(case2x2=out))
 	}
 
-	# Wald test to test average group effect, average time effect, and global interaction effect 
+	# Wald test to test average group effect, average time effect, and global interaction effect
 	wald.test <- function(group, time, subject, rscore, ind, ni)
 	{
 		n <- sum(ni);
@@ -213,17 +217,17 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		# unconditional time mean
 		tab <- t(matrix(mean.factor(rscore, group:time, ind), t, a))
         	t.mean <- as.vector(apply(tab, 2, mean));
-	
+
 		# Average group effect
-		p <- (R - 0.5)/N; # RTE group x time 
+		p <- (R - 0.5)/N; # RTE group x time
         	Pa <- I(a) - (1/a) * J(a)
 		Pt <- I(t) - (1/t) * J(t)
-		Pat <- kronecker(Pa, Pt)	
-	
+		Pat <- kronecker(Pa, Pt)
+
 		# second last equation of page 134
 		cpg <- sqrt(n) * Pa %*% kronecker(I(a), (1/t)*t(one(t))) %*% p;
 
-		# last equation of page 134 
+		# last equation of page 134
 		Sigma <- kronecker(Pa,  (1/t)*t(one(t))) %*% V %*%  kronecker(Pa, (1/t)*one(t));
 
 		# equation (8.10)
@@ -233,12 +237,12 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 	        df.a <- tr(cvc%*%ginv(cvc))
 		if(!is.na(Q.a) && (Q.a > 0)) pval.a <- round(1 - pchisq(Q.a, df.a),Inf)
 		else pval.a <- NA;
-		A <- c(W=Q.a, df=df.a, pval=pval.a); 
-	
-		# Average time effect, eqn (8.9)	
-		S <- kronecker((1/a)*t(one(a)), I(t)) %*% V %*% kronecker((1/a)*one(a), I(t)) 
+		A <- c(W=Q.a, df=df.a, pval=pval.a);
 
-		cpt <- Pt %*% t.mean;	
+		# Average time effect, eqn (8.9)
+		S <- kronecker((1/a)*t(one(a)), I(t)) %*% V %*% kronecker((1/a)*one(a), I(t))
+
+		cpt <- Pt %*% t.mean;
 
 		# equation (8.20)
         	cvc <- Pt %*% S %*% Pt
@@ -247,7 +251,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		if(!is.na(Q.t) && (Q.t > 0)) pval.t <- round(1 - pchisq(Q.t, df.t),Inf)
 		else pval.t <- NA;
 		T <- c(Q.t, df.t, pval.t);
-	
+
 		# Global interaction effect
         	Cat <- kronecker(Pa, Pt); # book notation of page 141
 
@@ -259,14 +263,14 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		else pval.at <- NA;
 		AT <- c(Q.at, df.at, pval.at);
 
-		# results 
+		# results
 		out.w <- rbind(A, T, AT);
 	        colnames(out.w) <- c("Statistic", "df", "p-value")
                 rownames(out.w) <- c(group.name,time.name,paste(group.name,":",time.name,sep=""))
 		out <- list(Wald.test=out.w);
 	}
 
-	# To test average group effect, average time effect, and global interaction effect 
+	# To test average group effect, average time effect, and global interaction effect
 	anova.test <- function(group, time, subject, rscore, ind, a, ni)
 	{
 		group <- as.factor(group)
@@ -296,32 +300,32 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		F.a <- t(cpg) %*% cpg/sum(diag(Pa %*% Sigma));
 		# equation (5.7)
 		df1.a <- sum(diag(Pa %*% Sigma))^2/sum(diag((Pa %*% Sigma) %*% (Pa %*% Sigma)));
-		if((!is.na(F.a))&&(!is.na(df1.a))&&(F.a > 0)&&(df1.a > 0)) pval.a<-1-pchisq(F.a*df1.a,df1.a) 
-		else pval.a<-NA;  
+		if((!is.na(F.a))&&(!is.na(df1.a))&&(F.a > 0)&&(df1.a > 0)) pval.a<-1-pchisq(F.a*df1.a,df1.a)
+		else pval.a<-NA;
 		A <- round(c(B=F.a, df=df1.a, pval=pval.a), Inf);
 
 		# average time effect
   	      	# equation (8.9)
  	       S <- kronecker((1/a)*t(one(a)), I(t)) %*% V %*% kronecker((1/a)*one(a), I(t))
- 
+
                cpt <- Pt %*% t.mean;
 
 		# equation (8.21)
 		F.t <- (n/N^2) * (t(cpt) %*% cpt)/sum(diag(Pt %*% S));
 		df1.t <- sum(diag(Pt %*% S))^2/sum(diag(Pt %*% S %*% Pt %*% S));
 		if((!is.na(F.t))&&(!is.na(df1.t))&&(F.t > 0)&&(df1.t > 0)) pval.t<-1-pchisq(F.t*df1.t,df1.t)
-		else pval.t<-NA;  
+		else pval.t<-NA;
 		T <- round(c(F.t, df1.t, pval.t),Inf);
 
 		# Global interaction effect
 		F.at <- n * t(p) %*% Pat %*% p/sum(diag(Pat %*% V));
 		df1.at <- sum(diag(Pat %*% V))^2/sum(diag(Pat %*% V %*% Pat %*% V));
-		if((!is.na(F.at))&&(!is.na(df1.at))&&(F.at > 0)&&(df1.at > 0)) pval.at<-1-pchisq(F.at*df1.at,df1.at) 
-		else pval.at<-NA;  
+		if((!is.na(F.at))&&(!is.na(df1.at))&&(F.at > 0)&&(df1.at > 0)) pval.at<-1-pchisq(F.at*df1.at,df1.at)
+		else pval.at<-NA;
 		AT <- round(c(F.at, df1.at, pval.at), Inf);
 		out.box <- rbind(A, T, AT);
 	        colnames(out.box) <- c("Statistic", "df", "p-value")
-                rownames(out.box) <- c(group.name,time.name,paste(group.name,":",time.name,sep=""))	
+                rownames(out.box) <- c(group.name,time.name,paste(group.name,":",time.name,sep=""))
 		# modified Box-approximation
 		df1 <- df(V, a, t, ni, ind)$df1
 		df2 <- df(V, a, t, ni, ind)$df2
@@ -367,7 +371,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 			else pval1 <- NA
 			out <- c(Q.s, df, pval);
 			out1 <- c(F.s, df1, pval1);
-			wald[i,] <- out;		
+			wald[i,] <- out;
 			anova[i,] <- out1;
 
 			# pattern effect
@@ -379,7 +383,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 				p.nor <- round((1 - pnorm(L)), Inf);
 				df1 <- ni[i] -1;
 				pval <- round((1 - pt(L, df1)), Inf);
-				normal[i,] <- c(L, p.nor, df1, pval);	
+				normal[i,] <- c(L, p.nor, df1, pval);
 			}
 		}
 
@@ -408,9 +412,9 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		names(out.pat) <- c("Statistic", "p-value(N)", "df", "p-value(T)")
 		Test <- rep(c(group.name,time.name,paste(group.name,":",time.name,sep="")), choose(a,2));
 		Pairs <- rep(0, 3*choose(a ,2));
-	
 
-		k <- 1; 
+
+		k <- 1;
 		ll <-1
 		for(i in 1:(a-1))
 		{
@@ -418,7 +422,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 			{
 				data.p <- data[data[,1]==i | data[,1]==j,]
 				ni.p <- matrix(c(ni[i],ni[j]), 2,1);
-			
+
 				nn <- sum(ni.p)
 				NN <- sum(data.p[,5]);
 
@@ -427,13 +431,13 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 				subj <- data.p[,3]
 				rs <- data.p[,4]
 				ind <- data.p[,5]
-	
+
 				V <- V(as.numeric(gr), tm, subj, rs, ind, 2, t, ni.p)$V
 				R <- V(as.numeric(gr), tm, subj, rs, ind, 2, t, ni.p)$R
-			
+
 				out[k:(k+2),] <- anova.test(gr, tm, subj, rs, ind, 2, ni.p)$ANOVA.test
 				Pairs[k:(k+2)] <- paste(group.name,lev.grp[i], ":",group.name,lev.grp[j],sep="")
-				k <- k + 3; 
+				k <- k + 3;
 
 				# pattern interactions
 				if(!is.null(w))
@@ -473,7 +477,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		w.g <- matrix(w.g, a, 1)
 		lambda <- solve(diag(c(ni))-I(a))
 		c <- Pa%*%w.g
-	
+
 		g <- (g.mean-.5)/N
 		Kn <- sqrt(n)*t(w.g)%*%Pa%*%g
 		sign <- t(c)%*%S%*%c
@@ -526,7 +530,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		return(n);
 	}
 
-	# variance Vi equation (8.18) 
+	# variance Vi equation (8.18)
 	Vi <- function(data)
 	{
 		time <- factor(data$time)
@@ -534,13 +538,13 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		srank <- data$rscore
 		indx <- data$indx
 
-		t <- nlevels(time)	
-		n0 <- nlevels(subj)	
-	
+		t <- nlevels(time)
+		n0 <- nlevels(subj)
+
 		# matrix of order subject x time, R_ik - R_i
 		srank.m <- matrix(tapply(srank, subj:time, sum), t, n0)
 		ind.m <- matrix(tapply(indx, subj:time, sum), t, n0)
-	
+
 		junk <- srank.m*ind.m;
 		t.junk <- t(ind.m);
 
@@ -551,7 +555,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 
 		for(i in 1:t)
 		{
-			for(j in 1:t) 
+			for(j in 1:t)
 			{
 				ls <- sum(t.junk[,i]);
 				if(i==j) V[i,i] <- sum(t.junk[,i]*junk1[,i]^2)/(ls*(ls-1))
@@ -613,7 +617,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		c <- kronecker(Pa, (1/t)*t(one(t)))
 		tt <- t(c)%*%ginv(c%*%t(c))%*%c
 		tem1 <- tt%*%V;
-		df1 <- (tr(tem1))^2/tr(tem1%*%tem1)	
+		df1 <- (tr(tem1))^2/tr(tem1%*%tem1)
 		dpr <- Pa*I(a)
 		mat <- kronecker(I(a), (1/t)*t(one(t)))
 		va <- mat%*%V%*%t(mat)
@@ -641,7 +645,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 	a <- length(glevel)
 
 	if((t*s)!=length(var))
-	stop("Number of levels of subject (",s, ") times number of levels of time (",t,") 
+	stop("Number of levels of subject (",s, ") times number of levels of time (",t,")
 	is not equal to the total number of observations (",length(var),").",sep="")
 
 #    time order vector
@@ -652,11 +656,11 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		tlevel2 <- unique(time)
 
 		if(length(tlevel)!=length(tlevel2))	# if the levels of the order is different from the one in the data
-		stop("Length of the time.order vector (",length(tlevel), ") 
+		stop("Length of the time.order vector (",length(tlevel), ")
 		is not equal to the levels of time vector (",length(tlevel2),").",sep="")
 
 		if(mean(sort(tlevel)==sort(tlevel2))!=1)     # if the elements in the time.order is different from the time levels
-		stop("Elements in the time.order vector is different from the levels specified in the time vector.",sep="")		
+		stop("Elements in the time.order vector is different from the levels specified in the time vector.",sep="")
 	}
 
 #    group order vector
@@ -667,11 +671,11 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		glevel2 <- unique(group)
 
 		if(length(glevel)!=length(glevel2))	# if the levels of the order is different from the one in the data
-		stop("Length of the group.order vector (",length(glevel), ") 
+		stop("Length of the group.order vector (",length(glevel), ")
 		is not equal to the levels of group vector (",length(glevel2),").",sep="")
 
 		if(mean(sort(glevel)==sort(glevel2))!=1)     # if the elements in the group.order is different from the group levels
-		stop("Elements in the group.order vector is different from the levels specified in the group vector.",sep="")		
+		stop("Elements in the group.order vector is different from the levels specified in the group vector.",sep="")
 	 }
 
 #    sort data
@@ -689,8 +693,8 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 		newtime[i]<-col
 		newgroup[i]<-which(group[i]==glevel)
 		sortvector[((col-1)*s+row)]<-i
-        }   
-	
+        }
+
 	subject<-newsubject[sortvector]
 	var<-var[sortvector]
 	time<-newtime[sortvector]
@@ -701,7 +705,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 	grouptemp<-order(group[1:s])
 	groupplus<-(rep(c(0:(t-1)),e=s))*s
 	groupsort<-(rep(grouptemp,t))+groupplus
-	
+
 	subject<-rep(c(1:s),t)
 	var<-var[groupsort]
 	time<-time[groupsort]
@@ -725,11 +729,11 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 
         if(description==TRUE)
         {
-           	cat(" F1 LD F1 Model ") 
+           	cat(" F1 LD F1 Model ")
            	cat("\n ----------------------- \n")
-           	cat(" Total number of observations: ",sum(ind),"\n") 
+           	cat(" Total number of observations: ",sum(ind),"\n")
            	cat(" Total number of subjects:  " , n,"\n")
-          	cat(" Total number of missing observations: ",N.na,"\n") 
+          	cat(" Total number of missing observations: ",N.na,"\n")
            	cat("\n Class level information ")
            	cat("\n ----------------------- \n")
 	   	cat(" Levels of", time.name, "(sub-plot factor time) : ", t,"\n")
@@ -754,7 +758,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
            	else
            	{
            		pattern.string<-"no pattern specified"
-           	}  
+           	}
            	if(!is.null(w.t))
            	{
             		pattern.string.t<-w.t
@@ -762,7 +766,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
            	else
            	{
             		pattern.string.t<-"no pattern specified"
-           	}   
+           	}
            	if(!is.null(w.g))
            	{
             		pattern.string.g<-w.g
@@ -770,8 +774,8 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
            	else
            	{
             		pattern.string.g<-"no pattern specified"
-           	}   
-        
+           	}
+
            	cat(" pattern.time (time effects) = Test against patterned alternatives in time using normal distribution (",pattern.string,")","\n")
           	cat(" pair.comparison = Tests for pairwise comparisions (without specifying a pattern)","\n")
           	cat(" pattern.pair.comparison = Test for pairwise comparisons with patterned alternatives in time (",pattern.string.t,")","\n")
@@ -779,7 +783,7 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
            	cat(" covariance = Covariance matrix","\n")
            	cat(" Note: The description output above will disappear by setting description=FALSE in the input. See the help file for details.","\n\n")
       }
-           	cat(" Check that the order of the time and group levels are correct.\n") 
+           	cat(" Check that the order of the time and group levels are correct.\n")
            	cat(" Time level:  " , paste(tlevel),"\n")
            	cat(" Group level:  " , paste(glevel),"\n")
            	cat(" If the order is not correct, specify the correct order in time.order or group.order.\n\n")
@@ -789,30 +793,35 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
 	tab <- t(matrix(mean.factor(rscore, group:time, ind), t, a))
         g.mean <- as.vector(apply(tab, 1, mean));
         t.mean <- as.vector(apply(tab, 2, mean));
-	
+
 	# covariance matrix
 	V2 <- V(group, time, subject, rscore, ind, a, t, ni)$V;
 	R <- V(group, time, subject, rscore, ind, a, t, ni)$R;
 
 	SING.COV <- FALSE
 	if(qr(V2)$rank < (t*a)) SING.COV <- TRUE
-	if(SING.COV) 
+	if(SING.COV)
 	{
 		cat("\n Warning(s):\n")
 		cat(" The covariance matrix is singular. \n")
-	}	
+	}
 
         sdat <- NULL
-	rte <- list(RTE=rte(group, time, ind, rscore));
+	rte <- list(RTE=rte(group, time, ind, rscore))
 
+	rte.plot<-data.frame(rte)
+	namen.plot<-rownames(rte.plot)[(a+1):(a+t)]
+	namen.plot.g<-rownames(rte.plot)[1:a]
+
+	#rte <- data.frame(rte(group, time, ind, rscore))
 	### case2x2 is available only when there is no missing observation in the 2-by-2 design.
 	### otherwise, it returns NULL.
-        if(a==2 && t==2 && N.na==0) 
+        if(a==2 && t==2 && N.na==0)
 	{
 		out2 <- case2x2(group, time, subject, rscore, ind)
 	}
-        else 
-	{  
+        else
+	{
 		out2 <- list(case2x2=NULL)
 	}
 	   wald.test.t <- wald.test(group, time, subject, rscore, ind, ni);
@@ -825,7 +834,30 @@ f1.ld.f1 <- function(var, time, group, subject, w.pat=NULL, w.t=NULL, w.g=NULL,
         if(!is.null(w.g)) pattern.g <- pattern.group(group, time, subject, rscore, ind, a, t, ni, g.mean, w.g)
         else pattern.g <- NULL
 
-        out <- c(sdat, rte, out2, pattern.g, list(covariance=V2))
-        return(out);
-}
+	if(show.covariance==FALSE)
+	{
+  		V2<-NULL
+	}
 
+        out <- c(sdat, rte, out2, pattern.g, list(covariance=V2))
+
+	if (plot.RTE==TRUE)
+	{
+		ptg<-expression(p[i][j])
+		rte.plot<-data.frame(rte)[,3][(a+t+1):(a+t+a*t)]
+
+		kk.time <-1:t
+		plot(kk.time,rte.plot[kk.time], pch=10, type="b",lwd=3,ylim=c(0,1.1),xaxt="n", xlab=time.name, ylab=ptg,cex.lab=1.5)
+		axis(1,at=kk.time, labels=namen.plot[kk.time])
+		group.id.help<-sort(c(rep(1:a,t)))
+
+		for (ss in 2:a)
+		{
+			points(kk.time,rte.plot[group.id.help==ss], pch=10, type="b",lwd=3,ylim=c(0,1.1),xaxt="n", xlab="",ylab=ptg,cex.lab=1.5,col=ss)
+		}
+
+		legend("top", col=c(1:a),namen.plot.g,pch=c(rep(10,a)),lwd=c(rep(3,a)) )
+		title(main=paste("Relative Effects"))
+	}
+        return(out)
+}
\ No newline at end of file
